fn detect_payment_type(payment_string: &str) -> PaymentStringTypeExpand description
Detects the payment type from the payment string prefix
fn detect_payment_type(payment_string: &str) -> PaymentStringTypeDetects the payment type from the payment string prefix